summaryrefslogtreecommitdiffstats
path: root/cpukit/score/include/rtems/score/object.h
diff options
context:
space:
mode:
authorJoel Sherrill <joel.sherrill@OARcorp.com>2008-08-04 19:46:13 +0000
committerJoel Sherrill <joel.sherrill@OARcorp.com>2008-08-04 19:46:13 +0000
commitdc112f3f4162d875078ddcbdcacd98e82c66862b (patch)
tree6184ce7b1b7e791fd7cb2550a9f6811639147459 /cpukit/score/include/rtems/score/object.h
parent2008-08-04 Joel Sherrill <joel.sherrill@OARcorp.com> (diff)
downloadrtems-dc112f3f4162d875078ddcbdcacd98e82c66862b.tar.bz2
2008-08-04 Joel Sherrill <joel.sherrill@OARcorp.com>
PR 1265/cpukit * score/include/rtems/score/object.h, score/src/objectallocatebyindex.c: Rename index argument to avoid warning when rtems.h and string.h are included at the same time by user code.
Diffstat (limited to 'cpukit/score/include/rtems/score/object.h')
-rw-r--r--cpukit/score/include/rtems/score/object.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/cpukit/score/include/rtems/score/object.h b/cpukit/score/include/rtems/score/object.h
index da1f4406ee..b488dd6d45 100644
--- a/cpukit/score/include/rtems/score/object.h
+++ b/cpukit/score/include/rtems/score/object.h
@@ -535,12 +535,12 @@ Objects_Control *_Objects_Allocate(
* free object control blocks.
*
* @param[in] information points to an object class information block.
* @param[in] index is the index of the object to allocate.
* @param[in] sizeof_control is the size of the object control block.
*/
Objects_Control *_Objects_Allocate_by_index(
Objects_Information *information,
- uint16_t index,
+ uint16_t the_index,
uint16_t sizeof_control
);
@@ -535,12 +535,12 @@ Objects_Control *_Objects_Allocate(
*
* @param[in] information points to an object class information block.
- * @param[in] index is the index of the object to allocate.
+ * @param[in] the_index is the index of the object to allocate.
* @param[in] sizeof_control is the size of the object control block.
*/